
# Slot: full_name


Optional string with extended full name for the namespace.

URI: [nwb_schema_language:full_name](https://w3id.org/p2p_ld/nwb-schema-language/full_name)


## Domain and Range

None &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [Namespace](Namespace.md)
